@@ -1,6 +1,6 @@
 #!/bin/sh
 
-mversion="V1.4.35"
+mversion="V1.6.1.20"
 
 echo "--- Asterisk IP/PABX $mversion Installation ---"
 
@@ -33,13 +33,10 @@ USR="codecs.conf \
      sip_notify.conf \
      cdr_mysql.conf \
      amd.conf \
-     queues.conf \
-     agents.conf \
-     iax.conf \
      jabber.conf \
-     gtalk.conf \
-     res_mysql.conf" \
-
+     gtalk.conf\
+     iax.conf \
+     res_mysql.conf "
 
 src=.
 dst=
@@ -60,8 +57,6 @@ mkdir -p $dst/var/lib/asterisk
 mkdir -p $dst/var/lib/asterisk/sounds
 mkdir -p $dst/var/lib/asterisk/keys
 mkdir -p $dst/var/lib/asterisk/mohmp3
-mkdir -p $dst/var/lib/asterisk/firmware
-mkdir -p $dst/var/lib/asterisk/firmware/iax
 
 echo "Installing asterisk binary..."
 install -m $perm_exec $src/bin/asterisk $dst/usr/sbin/
@@ -77,8 +72,8 @@ if [ "1" = "1" ]; then \
 	elif [ -f /etc/gentoo-release ]; then \
 		install -m $perm_exec $src/bin/rc.gentoo.asterisk $dst/etc/init.d/asterisk; \
 		/sbin/rc-update add asterisk default; \
-	elif [ -f /etc/mandrake-release ]; then \
-		install -m $perm_exec $src/bin/rc.mandrake.asterisk $dst/etc/rc.d/init.d/asterisk; \
+	elif [ -f /etc/mandriva-release ]; then \
+		install -m $perm_exec $src/bin/rc.mandriva.asterisk $dst/etc/rc.d/init.d/asterisk; \
   /sbin/chkconfig --add asterisk; \
 	elif [ -f /etc/SuSE-release -o -f /etc/novell-release ]; then \
 		install -m $perm_exec $src/bin/rc.suse.asterisk $dst/etc/init.d/asterisk; \
